#!perl -w
use Test::More tests => 14;

use strict;
use File::Temp qw( tempdir );
use DE_EPAGES::Core::API::File qw(DeleteDirectory);
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Database::API::Config qw( StoreType );

use DE_EPAGES::Installer::API::LanguagePack qw(
    GetLangPackURL
    GetUsedLanguages
    DictionaryXmlLocation
    LanguagePackLocation
    DownloadLanguagePack
    UntarLanguagePack
    GetLanguagesByVersion
    GetLanguageVersionList
);

RunScript( Debug => 1, Sub => sub {

    my $TestSite = defined $ENV{EPAGES_TESTSITE} ? $ENV{EPAGES_TESTSITE} : 'Store';

    my $GetUrl = join('', GetLangPackURL('es', '6.13.3'));
    my $ExpectedUrl = 'http://www.epages.com/LanguagePacks/6.13/es/langpack-es-epages613p3.tar.gz';
    ok( $GetUrl eq $ExpectedUrl, "GetLangPackURL('es', '6.13.3') -> $GetUrl");

    my ($StoreTypeLang, $StoreLang) = GetUsedLanguages([$TestSite], {Ignore => ['de']});
    my $StoreType = StoreType($TestSite);
    ok( $StoreTypeLang->{$StoreType}{'en'},  "GetUsedLanguages: StoreType=$StoreType Lang=en" );
    ok( $StoreLang->{'en'}{$TestSite},       "GetUsedLanguages: Store=$TestSite     Lang=en" );
    ok( !$StoreTypeLang->{$StoreType}{'de'}, "GetUsedLanguages: StoreType=$StoreType Ignore=de" );
    ok( !$StoreLang->{'de'}{$TestSite},      "GetUsedLanguages: Store=$TestSite     Ignore=de" );

    my $TempDir = tempdir();
    local $ENV{EPAGES_PATCHES} = $TempDir;

    my $GetLP = DownloadLanguagePack('es', '6.12.0');
    my $FoundLP = LanguagePackLocation('es', '6.12.0', {IfExists => 1});
    ok( $GetLP eq $FoundLP, "DownloadLanguagePack('es', '6.12.0') -> LanguagePackLocation('es', '6.12.0')");

    $FoundLP = UntarLanguagePack('es', '6.12.0', undef, {Print => 1});
    my $DictionaryXml = DictionaryXmlLocation(
        'es', { Dir => "$FoundLP/Cartridges", IfExists => 1});
    ok( $DictionaryXml, "DictionaryXmlLocation('es', {Dir => '$FoundLP/Cartridges'})");

    $GetLP = DownloadLanguagePack('ca', '6.13.1', "$TempDir/tmp" );
    $FoundLP = LanguagePackLocation(
        'ca', '6.13.1', {Dir => ['.',"$TempDir/tmp"], IfExists => 1});
    ok( $GetLP eq $FoundLP, "DownloadLanguagePack('ca', '6.13.1', '$TempDir/tmp') -> LanguagePackLocation('ca', '6.13.1', {Dir => ['.','$TempDir/tmp']})");

    $FoundLP = UntarLanguagePack('ca', '6.13.1', "$TempDir/tmp", {Print => 1} );
    $DictionaryXml = DictionaryXmlLocation(
        'ca', { Dir => "$FoundLP/Cartridges", IfExists => 1});
    ok( $DictionaryXml, "DictionaryXmlLocation('ca', { Dir => '$FoundLP/Cartridges'})");

    my @Languages = sort @{GetLanguagesByVersion('6.12.0', 'es it')};
    my @Expected = qw(es it);
    ok( @Languages ~~ @Expected, "GetLanguagesByVersion('6.12.0', 'es it') -> ". join(' ', @Languages) );

    @Languages = sort @{GetLanguagesByVersion('6.13.0', 'es any it')};
    @Expected = qw(ca da en-US es fi fr it nl no pt ru sv);
    ok( @Languages ~~ @Expected, "GetLanguagesByVersion('6.13.0', 'es any it') -> ". join(' ', @Languages) );

    @Languages = sort @{GetLanguagesByVersion('6.14.0')};
    @Expected = qw(ca cs da en-US es fi fr it nl no pt ru sv);
    ok( @Languages ~~ @Expected, "GetLanguagesByVersion('6.14.0') -> ". join(' ', @Languages) );

    @Languages = sort @{GetLanguagesByVersion('6.11', 'any')};
    @Expected = qw(ca da es fi fr it nl no pt ru sv);
    ok( @Languages ~~ @Expected, "GetLanguagesByVersion('6.11', 'any') -> ". join(' ', @Languages) );

    my @VersionList = sort @{GetLanguageVersionList('6.12 6.13.1')};
    @Expected = qw(6.12.0 6.12.1 6.12.2 6.12.3 6.13.1);
    ok( @VersionList ~~ @Expected, "GetLanguageVersionList('6.12 6.13.1') -> ". join(' ', @VersionList) );

    DeleteDirectory($TempDir, {'recursive' => 1});
});
